shapeshiftr: Analyze Group/Home Range Shape Shifts Using Location Data.
shapeshiftr.RdR package for detecting population range reconfiguration via inter-individual distances
Details
The package is designed for spatial and temporal analysis of location data, especially those multiple sampling sessions (seasons, years, sites, populations, etc).
Author
Maintainer: Nicola Love nicolalove@zoology.ubc.ca (GitHub = nicolalove)
Authors:
Sarah Otto (GitHub = spotto)