Data to showcase a population fragmenting into two subpopulations
split_population.RdA dataset containing locations of sampled animals over 2 years
Format
A data frame with 100 rows and 5 columns.
- x
Longitude of animal
- y
Latitude of animal
- year
Year animal was sampled
- random
A column containing data but not relevant to these functions
- id
The name of the animal sampled
Created by Nicola Love, by creating 3 bivariate normal distributions using MASS::mvrnorm(). All three distributions had a standard deviation of 15, the distribution in year 1 was centered at c(50,50), the two distributions in year 2 were centered at c(50,0) and c(50, 100).
Examples
data(split_population)